@@ -450,8 +450,12 @@ Ext.define('SoL.module.Players', {
 
     id: 'players-win',
     iconCls: 'players-icon',
-    launcherText: _('Players'),
-    launcherTooltip: _('<b>Players</b><br />Basic players management'),
+    launcherText: function() {
+        return _('Players');
+    },
+    launcherTooltip: function() {
+        return _('<b>Players</b><br />Basic players management.');
+    },
 
     config: {
         xtype: 'editable-grid',
@@ -508,6 +512,7 @@ Ext.define('SoL.module.Players', {
                     ]
                 });
                 callback(cfg);
+                me.app.on('logout', function() { delete cfg.metadata; }, me, { single: true });
             });
         } else {
             callback(cfg);
@@ -538,6 +543,7 @@ Ext.define('SoL.module.Players', {
                             selectionchange: function(model, records) {
                                 var num = records.length;
                                 var seltext = '';
+
                                 if(num>0) {
                                     seltext = ' (' + Ext.String.format(ngettext(
                                         // TRANSLATORS: this is used on the Players window,
@@ -545,7 +551,7 @@ Ext.define('SoL.module.Players', {
                                         '{0} selected', '{0} selected', num
                                     ), num) + ')';
                                 }
-                                win.setTitle(me.launcherText + filteredOn + seltext);
+                                win.setTitle(me.getLauncherText() + filteredOn + seltext);
                             }
                         }
                     }
@@ -606,8 +612,8 @@ Ext.define('SoL.module.Players', {
 
                 win = desktop.createWindow({
                     id: me.id,
-                    title: (me.windowTitle || me.launcherText) + filteredOn,
-                    taskbuttonTooltip: me.launcherTooltip,
+                    title: (me.windowTitle || me.getLauncherText()) + filteredOn,
+                    taskbuttonTooltip: me.getLauncherTooltip(),
                     iconCls: me.iconCls,
                     items: [config],
                     x: size.x,
@@ -851,7 +857,11 @@ Ext.define('SoL.module.MyPlayers', {
     init: function() {
         var me = this;
         var user = me.app.user;
-        me.config.dataURL += '?filter_idowner=' + (user.is_admin ? 'NULL' : user.user_id);
+        if(!me.config.orig_dataURL) me.config.orig_dataURL = me.config.dataURL;
+        me.config.dataURL = Ext.String.urlAppend(me.config.orig_dataURL,
+                                                 'filter_idowner=' + (user.is_admin
+                                                                      ? 'NULL'
+                                                                      : user.user_id));
         me.windowTitle = Ext.String.format(_('Players managed by {0}'), user.fullname);
         me.callParent();
     }
