@@ -351,8 +351,12 @@ Ext.define('SoL.module.Ratings', {
 
     id: 'ratings-win',
     iconCls: 'ratings-icon',
-    launcherText: _('Ratings'),
-    launcherTooltip: _('<b>Ratings</b><br />Basic ratings management'),
+    launcherText: function() {
+        return _('Ratings');
+    },
+    launcherTooltip: function() {
+        return _('<b>Ratings</b><br />Basic ratings management.');
+    },
 
     config: {
         xtype: 'editable-grid',
@@ -389,6 +393,7 @@ Ext.define('SoL.module.Ratings', {
                     ]
                 });
                 callback(cfg);
+                me.app.on('logout', function() { delete cfg.metadata; }, me, { single: true });
             });
         } else {
             callback(cfg);
@@ -420,8 +425,8 @@ Ext.define('SoL.module.Ratings', {
 
                 win = desktop.createWindow({
                     id: me.id,
-                    title: me.windowTitle || me.launcherText,
-                    taskbuttonTooltip: me.launcherTooltip,
+                    title: me.windowTitle || me.getLauncherText(),
+                    taskbuttonTooltip: me.getLauncherTooltip(),
                     iconCls: me.iconCls,
                     items: [me.config],
                     x: size.x,
@@ -501,7 +506,11 @@ Ext.define('SoL.module.MyRatings', {
     init: function() {
         var me = this;
         var user = me.app.user;
-        me.config.dataURL += '?filter_idowner=' + (user.is_admin ? 'NULL' : user.user_id);
+        if(!me.config.orig_dataURL) me.config.orig_dataURL = me.config.dataURL;
+        me.config.dataURL = Ext.String.urlAppend(me.config.orig_dataURL,
+                                                 'filter_idowner=' + (user.is_admin
+                                                                      ? 'NULL'
+                                                                      : user.user_id));
         me.windowTitle = Ext.String.format(_('Ratings managed by {0}'), user.fullname);
         me.callParent();
     }
