@@ -248,16 +248,14 @@ def auth_user(request):
                   'reload_l10n': reload_l10n,
                   'modules': [MODULES[m]['classname'] for m in MODULES
                               if not is_guest or m != 'upload'],
-                  'shortcuts': [translate_name(sc)
-                                for sc in [MODULES[m]['shortcut']
-                                           for m in MODULES
-                                           if 'shortcut' in MODULES[m] and (
-                                                   not is_guest or m != 'upload')]],
+                  'shortcuts': [] if is_guest else [translate_name(sc)
+                                                    for sc in [MODULES[m]['shortcut']
+                                                               for m in MODULES
+                                                               if 'shortcut' in MODULES[m]]],
                   'quickstart': [translate_name(qs)
                                  for qs in [MODULES[m]['quickstart']
                                             for m in MODULES
-                                            if 'quickstart' in MODULES[m] and (
-                                                    not is_guest or m != 'upload')]]
+                                            if 'quickstart' in MODULES[m]]]
               }
 
         get_request_logger(request, logger).info('New session for %s', fullname)
