@@ -182,7 +182,7 @@ def rankingForTurn(request):
     bucholz=dict(readonly=True, width=40, sortable=False),
     netscore=dict(readonly=True, width=40, sortable=False),
     totscore=dict(hidden=True, readonly=True, width=40, sortable=False),
-    prize=dict(hidden=True, width=55, sortable=False),
+    prize=dict(hidden=True, width=55, sortable=False, decimals=2, type='float'),
     rate=dict(label=_('Rate'),
               hint=_('Most recent Glicko rate of the competitor (if'
                      ' tourney is associated with a rating).'),
